//
//  Board.swift
//  Chapter 3 Photo Sharing
//
//  Created by Mini Projects on 15/05/2015.
//  Copyright (c) 2015 Packt Pub. All rights reserved.
//

import UIKit

class BoardView:UIView {
    
    class Element{
        var position:CGPoint? {
            didSet{
                self.view?.setNeedsDisplay()
            }
        }
        var view:BoardView?
        
        func draw(){
            fatalError("The function \(__FUNCTION__) shouldn't be called from the base class")
        }
    }
    
    
    class ElementBackground:BoardView.Element {
        var image:UIImage
        
        init(image:UIImage) {
            self.image = image
            super.init()
            self.position = CGPointZero
        }
        
        override func draw() {
            if let position = self.position {
                image.drawAtPoint(position)
            }
        }
    }
    
    class ElementPicture:BoardView.Element {
        var image: UIImage
        init(image: UIImage){
            self.image = image
            super.init()
        }
        
        override func draw() {
            if let position = self.position {
                let newPosition = CGPointMake(position.x - image.size.width / 2, position.y - image.size.height / 2 )
                image.drawAtPoint(newPosition)
            }
        }
    }
    
    class ElementText:BoardView.Element {
        var text:String
        var attributes:[String:AnyObject]
        init(text:String, attributes: [String:AnyObject]) {
            self.text = text
            self.attributes = attributes
            super.init()
        }
        
        override func draw() {
            if let position = self.position {
                text.drawAtPoint(position, withAttributes: attributes)
            }
        }
    }

    class ElementCircle:BoardView.Element {
        var initialPoint:CGPoint?
        override var position:CGPoint? {
            get {
                return super.position
            }
            set (value){
                if initialPoint == nil {
                    initialPoint = value
                }
                super.position = value
            }
        }
        
        override func draw() {
            if let initialPosition = self.initialPoint, position = self.position {
                let borderRect = CGRectMake(initialPosition.x, initialPosition.y, position.x - initialPosition.x, position.y - initialPosition.y)
                let context = UIGraphicsGetCurrentContext()
                CGContextSetRGBStrokeColor(context, 1.0, 1.0, 1.0, 1.0)
                CGContextSetRGBFillColor(context, 0.0, 1.0, 0.0, 1.0)
                CGContextSetLineWidth(context, 2.0)
                CGContextFillEllipseInRect (context, borderRect)
                CGContextStrokeEllipseInRect(context, borderRect)
            }
        }
    } // class end
    
    private var elements = [Element]()
    
    func addElement(element:BoardView.Element){
        element.view = self
        elements.append(element)
        setNeedsDisplay()
    }

    override func drawRect(rect: CGRect) {
        for element in elements {
            element.draw()
        }
    }
    
    func getImage() -> UIImage {
        UIGraphicsBeginImageContext(self.frame.size)
        self.drawViewHierarchyInRect(self.frame, afterScreenUpdates: true)
        let image = UIGraphicsGetImageFromCurrentImageContext()
        UIGraphicsEndImageContext()
        return image
    
    }
} // class end
