//
//  EditPictureViewController.swift
//  Chapter 3 Photo Sharing
//
//  Created by Mini Projects on 15/05/2015.
//  Copyright (c) 2015 Packt Pub. All rights reserved.
//

import UIKit
import Social

class EditPictureViewController:UIViewController {
    
    
    @IBOutlet var boardView: BoardView!
    var currentElement:BoardView.Element?
    var photo:UIImage!
    
    override func viewDidLoad() {
        let element = BoardView.ElementBackground(image: UIImage(CGImage: photo.CGImage!, scale: 2, orientation: photo.imageOrientation))
        boardView.addElement(element)
        let gesture = UIPanGestureRecognizer(target: self, action: Selector("dragging:"))
        boardView.addGestureRecognizer(gesture)
    }
    
    func dragging(gesture:UIPanGestureRecognizer){
        if let currentElement = self.currentElement {
            currentElement.position = gesture.locationInView(self.boardView)
            if gesture.state == .Ended {
                self.currentElement = nil
            }
        }
    }
    
    @IBAction func addCircle(sender: UIButton) {
        currentElement = BoardView.ElementCircle()
        boardView.addElement(currentElement!)
    }
    
    @IBAction func addHat(sender: UIButton) {
        if let image = UIImage(named: "hat") {
            currentElement = BoardView.ElementPicture(image: image)
            boardView.addElement(currentElement!)
        }
    }
    
    @IBAction func addText(sender: UIButton) {
        let alertController = UIAlertController(title: "Text", message: "Please introduce your text", preferredStyle: .Alert)
        alertController.addTextFieldWithConfigurationHandler { (textfield) -> Void in
            textfield.placeholder = "Write a message"
        }
        let action = UIAlertAction(title: "OK", style: .Default) { (action) -> Void in
            let text = alertController.textFields!.first!.text!
            let textFontAttributes:[String:AnyObject] = [
                NSFontAttributeName: UIFont(name: "Helvetica", size: CGFloat(24.0))!,
                NSForegroundColorAttributeName: UIColor.redColor(),
                NSParagraphStyleAttributeName: NSMutableParagraphStyle.defaultParagraphStyle()
            ]
            
            self.currentElement = BoardView.ElementText(text: text, attributes: textFontAttributes)
            self.boardView.addElement(self.currentElement!)
        }
        alertController.addAction(action)
        
        let cancel = UIAlertAction(title: "Cancel", style: .Cancel) { (_) -> Void in
        }
        alertController.addAction(cancel)
        
        self.presentViewController(alertController, animated: true, completion: nil)
    }
    
    
    
    
    
    
    @IBAction func done(sender: UIButton) {
        
        if SLComposeViewController.isAvailableForServiceType(SLServiceTypeFacebook) {
            let fbViewController = SLComposeViewController(forServiceType: SLServiceTypeFacebook)
            fbViewController.addImage(boardView.getImage())
            fbViewController.completionHandler = {(result) -> Void in
                switch result {
                case .Cancelled:
                    ()
                case .Done:
                    self.performSegueWithIdentifier("restart", sender: self)
                }
            }
            presentViewController(fbViewController, animated: true, completion: nil)
        }
        else {
            let alertController = UIAlertController(title: "Log in", message: "You must log in on Facebook", preferredStyle: .Alert)
            let action = UIAlertAction(title: "Dismiss", style: .Cancel, handler: { (_) -> Void in
            })
            alertController.addAction(action)
            presentViewController(alertController, animated: true, completion: nil)
        }
        
    }// end done
    
    
} // class end
