//
//  AccessoryViewController.swift
//  Chapter 4 Home Automation
//
//  Created by Mini Projects on 03/06/2015.
//  Copyright (c) 2015 Packt Pub. All rights reserved.
//

import Foundation
import UIKit
import HomeKit

class AccessoryViewController: UIViewController, HMAccessoryBrowserDelegate, HMAccessoryDelegate {

    
    var accessoryBrowser = HMAccessoryBrowser()
    var home:HMHome!
    var room:HMRoom!
    var accessory:HMAccessory?
    var characteristic:HMCharacteristic?
    var acceptsNotifications = false
    var expectedAccesory:String {
        get {
            fatalError("expectedAccesory should be called from an inherited class")
        }
    }
    var expectedService:String {
        get {
            fatalError("expectedService should be called from an inherited class")
        }
    }
    var expectedCharacteristic:String {
        get {
            fatalError("expectedCharacteristic should be called from an inherited class")
        }
    }
    
    
    override func viewDidLoad() {
        super.viewDidLoad()

        for accessory in room.accessories {
            if accessory.name == expectedAccesory {
                self.accessory = accessory
                self.accessory?.delegate = self
            }
        }
    }
    
    override func viewDidAppear(animated: Bool) {
        super.viewDidAppear(animated)
        if self.accessory == nil {
            accessoryBrowser.delegate = self
            accessoryBrowser.startSearchingForNewAccessories()
        }else {
            accessoryIsReady()
        }
    }
    

    func accessoryBrowser(browser: HMAccessoryBrowser, didFindNewAccessory accessory: HMAccessory) {
        print("Found: \(accessory.name)")
        if accessory.name == expectedAccesory {
            home.addAccessory(accessory, completionHandler: { (error) -> Void in
                if error != nil {
                    self.displayError(error!)
                    return
                }
                
                self.home.assignAccessory(accessory, toRoom: self.room, completionHandler: { (error) -> Void in
                    if error != nil {
                        self.displayError(error!)
                        return
                    }
                    
                    self.accessory = accessory
                    self.accessory?.delegate = self
                    self.accessoryIsReady()
                })
            })
        }
    }
    
    func accessoryIsReady(){
        let accessory = self.accessory!
        for service in accessory.services {
            if service.serviceType != self.expectedService {
                continue
            }
            for characteristic in service.characteristics {
                if characteristic.characteristicType == self.expectedCharacteristic {
                    if let _ = characteristic.properties.indexOf(HMCharacteristicPropertySupportsEventNotification){
                        self.acceptsNotifications = true
                        characteristic.enableNotification(true, completionHandler: { (error) -> Void in
                            if error != nil {
                                self.displayError(error!)
                                return
                            }
                        })
                    }
                    self.characteristic = characteristic
                    self.readCharacteristicValue()
                }
            }
        }
    }
    
    func accessory(accessory: HMAccessory, service: HMService, didUpdateValueForCharacteristic characteristic: HMCharacteristic) {
        self.readCharacteristicValue()
    }

    
    func readCharacteristicValue(){
        // this function should be overridden
    }
    
} // end class