//
//  ViewController.swift
//  Chapter 4 Home Automation
//
//  Created by Mini Projects on 01/06/2015.
//  Copyright (c) 2015 Packt Pub. All rights reserved.
//

import UIKit
import HomeKit

class SelectRoomViewController: UIViewController, HMHomeManagerDelegate{
    
    let homeManager = HMHomeManager()
    
    @IBOutlet weak var livingRoomButton: UIButton!
    @IBOutlet weak var garageButton: UIButton!
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        homeManager.delegate = self
    }
    
    
    func homeManagerDidUpdateHomes(manager: HMHomeManager) {
        if manager.homes.count == 0 {
            // There is no home set up, we must do it now.
            manager.addHomeWithName("Home Sweet Home", completionHandler: { (home, error) in
                if error != nil {
                    self.displayError(error!)
                    return
                }
                
                // as it is a new home we can set its rooms now
                home?.addRoomWithName("Living Room", completionHandler: {(room, error)-> Void in
                    if error != nil {
                        self.displayError(error!)
                        return
                    }
                    self.livingRoomButton.enabled = true
                })
                home?.addRoomWithName("Garage", completionHandler: {(room, error)-> Void in
                    if error != nil {
                        self.displayError(error!)
                        return
                    }
                    self.garageButton.enabled = true
                })
            })
        }else {
            livingRoomButton.enabled = true
            garageButton.enabled = true
        }
    }
    
    func getRoom(name:String) -> HMRoom? {
        if let home = homeManager.homes.first{
            for room in home.rooms {
                if room.name == name {
                    return room
                }
            }
        }
        return nil
    }
    
    override func prepareForSegue(segue: UIStoryboardSegue, sender: AnyObject?) {
        if sender === livingRoomButton {
            let accessoryViewController = segue.destinationViewController as! LivingRoomViewController
            accessoryViewController.home = homeManager.homes.first!
            accessoryViewController.room = getRoom("Living Room")
        }else if sender === garageButton {
            let accessoryViewController = segue.destinationViewController as! AccessoryViewController
            accessoryViewController.home = homeManager.homes.first!
            accessoryViewController.room = getRoom("Garage")
        }
    }
    
    @IBAction func unwindMainMenu(sege: UIStoryboardSegue){
        
    }
    
}

