//
//  GameScene.swift
//  Chapter 6 DinoSurf
//
//  Created by Mini Projects on 05/07/2015.
//  Copyright (c) 2015 Packt Pub. All rights reserved.
//

import SpriteKit
import CoreMotion

class GameScene: SKScene {
    
    var wave:SKSpriteNode!
    var dino:SKSpriteNode!
    
    var duration = 3.0
    
    var manager:CMMotionManager!
    
    private enum Direction: Int {
        case Left = -1,
        Right = 1
    }
    
    private enum Speed : Int{
        case Idle = 0,
        Slow = 5,
        Fast = 10
    }
    
    override func didMoveToView(view: SKView) {
        /* Setup your scene here */
        let appTitle = SKLabelNode(fontNamed:"Chalkboard SE")
        appTitle.text = "DinoSurf";
        appTitle.fontColor = UIColor.blueColor()
        appTitle.fontSize = 65;
        appTitle.position = CGPoint(x:CGRectGetMidX(self.frame), y:CGRectGetHeight(self.frame) - CGRectGetHeight(appTitle.frame));
        self.addChild(appTitle)
        
        let scoreText = SKLabelNode(fontNamed:"Chalkboard SE")
        scoreText.text = "Score:";
        scoreText.name = "label_score"
        scoreText.fontColor = UIColor.blueColor()
        scoreText.fontSize = 25;
        scoreText.position = CGPoint(x: 0 , y:CGRectGetHeight(self.frame) - CGRectGetHeight(scoreText.frame));
        self.addChild(scoreText)
        
        let levelText = SKLabelNode(fontNamed:"Chalkboard SE")
        levelText.text = "Level:";
        levelText.name = "label_level"
        levelText.fontColor = UIColor.blueColor()
        levelText.fontSize = 25;
        levelText.position = CGPoint(x: 0 , y:CGRectGetMinY(scoreText.frame) - CGRectGetHeight(levelText.frame));
        self.addChild(levelText)
        
        let livesText = SKLabelNode(fontNamed:"Chalkboard SE")
        livesText.text = "Lives:";
        livesText.name = "label_lives"
        livesText.fontColor = UIColor.blueColor()
        livesText.fontSize = 25;
        livesText.position = CGPoint(x: 0 , y:CGRectGetMinY(levelText.frame) - CGRectGetHeight(livesText.frame));
        self.addChild(livesText)
        
        self.refreshLabels()
        
        let waveUp = SKAction.moveByX(0, y: 20, duration: 0.5)
        let waveDown = SKAction.moveByX(0, y: -20, duration: 0.5)
        let waveUpAndDown = SKAction.sequence([waveUp, waveDown])
        let waveMove = SKAction.repeatActionForever(waveUpAndDown)
        
        wave = SKSpriteNode(imageNamed: "wave")
        wave.name = "wave"
        wave.runAction(waveMove)
        self.addChild(wave)
        
        dino = SKSpriteNode(imageNamed: "dinosaur")
        dino.name = "dino"
        dino.runAction(waveMove)
        self.addChild(dino)
        
        self.startupPosition()
        
        // water actions
        let waterRight = SKAction.moveByX(10, y: 0, duration: 0.5)
        let waterLeft = SKAction.moveByX(-10, y: 0, duration: 0.5)
        let waterRightAndLeft = SKAction.sequence([waterRight, waterLeft])
        let waterMove = SKAction.repeatActionForever(waterRightAndLeft)
        
        // water node
        let water = SKSpriteNode(imageNamed: "water")
        water.position = CGPoint(x: CGRectGetMidX(self.frame), y: 0)
        water.runAction(waterMove)
        self.addChild(water)
        
        
        manager = CMMotionManager()
        manager.startAccelerometerUpdates()
    }
    
    
    
    override func touchesBegan(touches: Set<UITouch>, withEvent event: UIEvent?) {
        self.paused = !self.paused
    }
    
    override func update(currentTime: CFTimeInterval) {
        if let accelerationData = self.manager.accelerometerData {
            var speed = Speed.Idle
            var direction = Direction.Right
            if abs(accelerationData.acceleration.y) >= 0.5 {
                speed = .Fast
            }else  if abs(accelerationData.acceleration.y) >= 0.25 {
                speed = .Slow
            }
            
            if accelerationData.acceleration.y > 0 {
                direction = .Left
            }
            
            self.moveWave(direction, speed: speed)
        }
        
        if let _ = childNodeWithName("enemy") {
            self.checkOverlaps()
        }
        else {
            self.createEnemy()
        }
    }
    
    private func createEnemy(){
        if arc4random_uniform(2) == 0 {
            self.createFish()
        }else {
            self.createBird()
        }
    }
    
    private func createBird(){
        let enemy = SKSpriteNode(imageNamed: "bird")
        let positionX = Int(arc4random_uniform(UInt32(CGRectGetWidth(self.frame))))
        enemy.position = CGPoint(x: positionX, y: Int(CGRectGetHeight(self.frame)))
        enemy.name = "enemy"
        
        let birdSound = SKAction.playSoundFileNamed("vulture.wav", waitForCompletion: false)
        
        var destination = CGPoint()
        destination.y = CGFloat(arc4random_uniform(UInt32(CGRectGetHeight(self.frame))))
        if CGFloat(positionX) < CGRectGetMidX(self.frame) {
            enemy.xScale = -1
            destination.x = CGRectGetWidth(self.frame)
        }else{
            destination.x = 0
        }
        let movement = SKAction.moveTo(destination, duration: self.duration)
        
        let remove = SKAction.removeFromParent()
        let sequence = SKAction.sequence([birdSound, movement, remove])
        
        enemy.runAction(sequence) {() in
            self.increaseScore()
        }
        self.addChild(enemy)
    }
    
    private func createFish() {
        let enemy = SKSpriteNode(imageNamed: "fish")
        let positionX = Int(arc4random_uniform(UInt32(CGRectGetWidth(self.frame))))
        enemy.position = CGPoint(x: positionX, y: 0)
        enemy.name = "enemy"
        enemy.zRotation = CGFloat(M_PI / 2)
        
        let stepDuration = self.duration / 3
        
        let wait = SKAction.waitForDuration(stepDuration)
        
        let splashSound = SKAction.playSoundFileNamed("splash.wav", waitForCompletion: false)
        let up = SKAction.moveToY(CGRectGetMidY(self.frame), duration: stepDuration)
        
        let fallRotation = SKAction.rotateByAngle(CGFloat(M_PI), duration: 0)
        let down = SKAction.moveToY(0, duration: stepDuration)
        
        let remove = SKAction.removeFromParent()
        let sequence = SKAction.sequence([ wait, splashSound, up, fallRotation, down, remove])
        enemy.runAction(sequence) {() in
            self.increaseScore()
        }
        self.addChild(enemy)
    }
    
    private func increaseScore(){
        if self.children.indexOf(self.dino) == nil {
            return
        }
        self.score++
        #if DEBUG
            let levelup = 3
            #else
            let levelup = 10
        #endif
        if score % levelup == 0 {
            let levelup = SKAction.playSoundFileNamed("levelup.wav", waitForCompletion: false)
            self.dino.runAction(levelup)
            level++
            duration *= 0.8
        }
        self.refreshLabels()
    }
    
    
    
    
    var score = 0
    var lives = 2
    var level = 1
    
    private func refreshLabels(){
        (self.childNodeWithName("label_score") as? SKLabelNode)?.text = "Score: \(score)"
        (self.childNodeWithName("label_level") as? SKLabelNode)?.text = "Level: \(level)"
        (self.childNodeWithName("label_lives") as? SKLabelNode)?.text = "Lives: \(lives)"
    }
    
    private func startupPosition(){
        wave.position = CGPoint(x: CGRectGetMidX(self.frame), y: 100)
        var dinoPosition = wave.position
        dinoPosition.y = wave.position.y + 3 * wave.frame.size.height / 4
        dino.position = dinoPosition
    }
    
    private func checkOverlaps(){
        if let _ = self.children.indexOf(self.dino) {
            self.enumerateChildNodesWithName("enemy") { enemy, stop in
                if enemy.intersectsNode(self.dino) {
                    let crunch = SKAction.playSoundFileNamed("crunch.wav", waitForCompletion: false)
                    self.dino.runAction(crunch)
                    enemy.removeFromParent()
                    self.decreaseLife()
                }
            }
        }
    }
    
    private func decreaseLife() {
        if self.lives > 0 {
            self.lives--
            self.startupPosition()
            self.refreshLabels()
        }
        else {
            dino.removeFromParent()
            let gameoverLabel = SKLabelNode(fontNamed:"Chalkboard SE")
            gameoverLabel.position.x = CGRectGetMidX(self.frame)
            gameoverLabel.position.y = CGRectGetMidY(self.frame)
            gameoverLabel.fontSize = 65
            gameoverLabel.text = "Game Over"
            self.addChild(gameoverLabel)
        }
    }
    
    
    private func moveWave(direction:Direction, speed:Speed){
        if speed == .Idle || self.paused {
            return
        }
        
        let offset = CGFloat(direction.rawValue * speed.rawValue)
        if self.wave.position.x + offset > 0 && self.wave.position.x + offset < CGRectGetMaxX(self.frame) {
            self.wave.position.x += offset
            self.dino.position.x += offset
        }
    }
}
