//
//  SupplyStatusInterfaceController.swift
//  Chapter 7 Fridge Control
//
//  Created by Mini Projects on 28/07/2015.
//  Copyright © 2015 Packt Pub. All rights reserved.
//

import Foundation
import WatchKit
import WatchConnectivity

class SupplyStatusInterfaceController: WKInterfaceController, WCSessionDelegate {
    
    @IBOutlet var statusLabel: WKInterfaceLabel!
    @IBOutlet var statusImage: WKInterfaceImage!
    @IBOutlet var supermarketButton: WKInterfaceButton!
    
    var supermarketData:[String:AnyObject]?
    var rowInfo:RowInfo!
    
    override func awakeWithContext(context: AnyObject?) {
        super.awakeWithContext(context)
        self.rowInfo = context as! RowInfo
        statusLabel.setText("\(rowInfo.title) Status")
    }
    
    override func didAppear() {
        let session = WCSession.defaultSession()
        session.delegate = self
        session.activateSession()
        
        
        session.sendMessage(["request":"status",
            "type":rowInfo.key],
            replyHandler: { (reply) -> Void in
                // Handle reply
                dispatch_async(dispatch_get_main_queue(), { () -> Void in
                    let percentage = Int(reply["value"] as! Float * 100.0)
                    self.statusImage.setImageNamed("status\(percentage)")
                })
            },
            errorHandler: { (error) -> Void in
                // Handle error
                print(error.localizedDescription)
                
        })
        
        
        
        session.sendMessage(["request":"supermarket"],
            replyHandler: { (reply) -> Void in
                // Handle reply
                dispatch_async(dispatch_get_main_queue(), { () -> Void in
                    if let value = reply["value"] as? [String:AnyObject]{
                        self.supermarketData = value
                        self.supermarketButton.setHidden(false)
                    }else {
                        self.supermarketButton.setHidden(true)
                    }
                })
            },
            errorHandler: { (error) -> Void in
                // Handle error
                print(error.localizedDescription)
                
        })
    }
    
    
    
    
    override func contextForSegueWithIdentifier(segueIdentifier: String) -> AnyObject? {
        if segueIdentifier == "mapsegue" {
            return self.supermarketData
        }
        return nil
    }
    
} // end SupplyStatusInterfaceController class
