//
//  AddSupplyViewController.swift
//  Chapter 7 Fridge Control
//
//  Created by Mini Projects on 14/07/2015.
//  Copyright © 2015 Packt Pub. All rights reserved.
//

import Foundation
import UIKit

class AddSuppliesViewController: UIViewController, UIPickerViewDataSource, UIPickerViewDelegate, UITextFieldDelegate {
    
    
    @IBOutlet var productNameTextField: UITextField!
    @IBOutlet var productTypePicker: UIPickerView!
    @IBOutlet var durationPicker: UIPickerView!
    
    private let productTypes = [
        SupplyType.Drink.rawValue.capitalizedString,
        SupplyType.Food.rawValue.capitalizedString,
        SupplyType.Dessert.rawValue.capitalizedString]
    private let durationUnit = ["Day", "Week", "Month"]
    private let fridge = Fridge.mainFridge()
    
    
    override func viewDidLoad() {
        super.viewDidLoad()
        self.setup()
    }
    
    func setup(){
        self.productNameTextField.text = ""
        self.productNameTextField.becomeFirstResponder()
        // Food is the default supply
        self.productTypePicker.selectRow(1, inComponent: 0, animated: true)
        // 1 day is the default duration
        self.durationPicker.selectRow(0, inComponent: 0, animated: true)
        self.durationPicker.selectRow(0, inComponent: 1, animated: true)
    }
    
    @IBAction func addProductAction(sender: UIButton!) {
        let name = self.productNameTextField.text!
        if name == "" {
            self.productNameTextField.becomeFirstResponder()
            return
        }

        let type:SupplyType
        switch productTypePicker.selectedRowInComponent(0) {
        case 0:
            type = .Drink
        case 1:
            type = .Food
        case 2:
            type = .Dessert
        default:
            fatalError("Wrong index \(productTypePicker.selectedRowInComponent(0)) on file \(__FILE__) near line \(__LINE__)")
        }
        
        let period:UInt
        switch durationPicker.selectedRowInComponent(1){
        case 0:
            period = 1
        case 1:
            period = 7
        case 2:
            period = 30
        default:
            fatalError("Wrong index \(productTypePicker.selectedRowInComponent(0)) on file \(__FILE__) near line \(__LINE__)")
        }
        
        let duration = UInt(self.durationPicker.selectedRowInComponent(0) + 1) * period * Fridge.cycleUnit
        let supply = Supply(name: name, type: type, duration: duration)
        self.fridge.addSupply(supply)
        
        self.setup()
    }
    
    // MARK: - Picker view data source function.
    func numberOfComponentsInPickerView(pickerView: UIPickerView) -> Int{
        if pickerView === self.productTypePicker {
            return 1
        }else {
            return 2
        }
    }
    
    func pickerView(pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        if pickerView === self.productTypePicker {
            return productTypes.count
        }else {
            return component == 0 ? 7 : self.durationUnit.count
        }
    }
    
    
    // MARK: - Picker view delegate
    func pickerView(pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        switch (pickerView, component){
        case (self.productTypePicker, _):
            return productTypes[row]
        case (self.durationPicker, 0):
            return String(row + 1)
        case (self.durationPicker, 1):
            return self.durationUnit[row]
        default:
            return nil
        }
    }
    
    
    // MARK: - Text field delegate
    func textFieldShouldReturn(textField: UITextField) -> Bool{
        textField.resignFirstResponder()
        return true
    }
    
    
}// end AddSuppliesViewController
