//
//  Fridge.swift
//  Chapter 7 Fridge Control
//
//  Created by Mini Projects on 17/07/2015.
//  Copyright © 2015 Packt Pub. All rights reserved.
//

import Foundation


class Fridge {
    private static var instance:Fridge?
    #if DEBUG
    // on debug mode 1 day will be 10 seconds
    static let cycleUnit = UInt(10)
    #else
    static let cycleUnit = UInt(60 * 60 * 24)
    #endif
    static let cycleTime = UInt(30)
    static let cycleThreshold = 0.2
    
    private var supplies = [SupplyType: [Supply]]()
    private let types:[SupplyType] = [.Drink, .Food, .Dessert]
    
    var notified = [SupplyType.Food: false,
        SupplyType.Drink: false,
        SupplyType.Dessert:false]
    
    private init(){
        for type in types {
            supplies[type] = [Supply]()
        }
    }
    
    class func mainFridge() -> Fridge {
        if Fridge.instance == nil {
            Fridge.instance = Fridge()
        }
        return Fridge.instance!
    }
    
    func addSupply(supply:Supply){
        supplies[supply.type]?.append(supply)
        self.notified[supply.type] = false
    }
    
    func consume(seconds:UInt){
        for type in types {
            if let currentSupplies = supplies[type] {
                var time = seconds
                for element in currentSupplies {
                    time = element.consume(time)
                }
            }
        }
    }
    
    func remainingTime(supplyType:SupplyType) -> UInt{
        return supplies[supplyType]!.reduce(0, combine: { (sum, element) -> UInt in
            return sum + element.endEstimation()
        })
    }
    
    func cyclePercentageFor(supplyType:SupplyType) -> Float {
        let percentage = Float(self.remainingTime(supplyType)) / Float(Fridge.cycleUnit * Fridge.cycleTime)
        if percentage > 1.0 {
            return 1.0
        }
        return percentage
    }
    
    func compress(){
       for key in self.supplies.keys {
            if let _ = supplies[key], _ = supplies[key]!.first{
                while supplies[key]!.count > 0 && supplies[key]!.first!.endEstimation() == 0  {
                    supplies[key]!.removeAtIndex(0)
                }
            }
        }
    }
} // fridge end


