//
//  FridgeStatusViewController.swift
//  Chapter 7 Fridge Control
//
//  Created by Mini Projects on 17/07/2015.
//  Copyright © 2015 Packt Pub. All rights reserved.
//

import Foundation
import UIKit
import CoreLocation

class FridgeStatusViewController: UIViewController {
    
    @IBOutlet var goToTheSupermarketButton: UIButton!
    @IBOutlet var statusLabel: UILabel!
    @IBOutlet var drinkBar: UIProgressView!
    @IBOutlet var foodBar: UIProgressView!
    @IBOutlet var dessertBar: UIProgressView!
    let fridge = Fridge.mainFridge()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        var lowLevel = [String]()
        
        let drinkPercentage = fridge.cyclePercentageFor(.Drink)
        drinkBar.progress = drinkPercentage
        if drinkPercentage <= 0.2 {
            lowLevel.append(SupplyType.Drink.rawValue)
        }
        
        let foodPercentage = fridge.cyclePercentageFor(.Food)
        foodBar.progress = foodPercentage
        if foodPercentage <= 0.2 {
            lowLevel.append(SupplyType.Food.rawValue)
        }
        
        let dessertPercentage = fridge.cyclePercentageFor(.Dessert)
        dessertBar.progress = dessertPercentage
        if dessertPercentage <= 0.2 {
            lowLevel.append(SupplyType.Dessert.rawValue)
        }
        
        
        if drinkPercentage == 0 &&
            foodPercentage == 0 &&
            dessertPercentage == 0 {
                statusLabel.text = "The fridge is empty!!"
                goToTheSupermarketButton.hidden = false
        }else if lowLevel.count == 0 {
                statusLabel.text = "The fridge has enough supplies"
            goToTheSupermarketButton.hidden = true
        }else {
            let join = lowLevel.joinWithSeparator(", ")
            statusLabel.text = "The fridge is running out of: \(join)"
            goToTheSupermarketButton.hidden = false
        }
        
    }
    
    @IBAction func goToTheSupermarket(sender: UIButton) {
        let supermarket = Supermarket.defaultSupermarket()
        func openMap(){
           let mapviewcontroller = self.storyboard!.instantiateViewControllerWithIdentifier("supermarketviewcontroller")
            self.presentViewController(mapviewcontroller, animated: true, completion: nil)
        }
        
        if let _ = supermarket.address {
            openMap()
        }
        else {
            let alertController = UIAlertController(title: "Address not found", message: "There is no supermarket address set, please introduce it.", preferredStyle: .Alert)
            alertController.addTextFieldWithConfigurationHandler(nil)
            
            let acceptAction = UIAlertAction(title: "Ok", style: .Default, handler: { (action) -> Void in
                let address:String = alertController.textFields![0].text!
                let geocoder = CLGeocoder()
                geocoder.geocodeAddressString(address, completionHandler: { (placemarks:[CLPlacemark]?, error:NSError?) -> Void in
                    if let error = error {
                        print(error.localizedDescription)
                    }
                    if let placemarks = placemarks where placemarks.count > 0 {
                        supermarket.address = address
                        supermarket.latitude = placemarks[0].location!.coordinate.latitude
                        supermarket.longitude = placemarks[0].location!.coordinate.longitude
                        openMap()
                    }
                })

            })
            alertController.addAction(acceptAction)
            
            let cancelAction = UIAlertAction(title: "Cancel", style: .Cancel, handler: nil)
            alertController.addAction(cancelAction)
            self.presentViewController(alertController, animated: true, completion: nil)
        } // end else
    } // end goToSupermarket method
}// end FridgeStatusViewController class