//
//  MapViewController.swift
//  Chapter 7 Fridge Control
//
//  Created by Mini Projects on 18/07/2015.
//  Copyright © 2015 Packt Pub. All rights reserved.
//

import Foundation
import UIKit
import MapKit
import CoreLocation

class MapViewController:UIViewController, MKMapViewDelegate, UITableViewDataSource {

    @IBOutlet var mapView: MKMapView!
    @IBOutlet var stepsTableView: UITableView!
    var steps:[MKRouteStep]?
    let locationManager = CLLocationManager()
    
    override func viewDidLoad() {
        super.viewDidLoad()

        locationManager.requestWhenInUseAuthorization()
        locationManager.startUpdatingLocation()
        
        let supermarket = Supermarket.defaultSupermarket()
        let coordinate = CLLocationCoordinate2DMake(supermarket.latitude!, supermarket.longitude!)
        let placemark = MKPlacemark(coordinate: coordinate, addressDictionary: nil)
        let destination = MKMapItem(placemark: placemark)
        destination.name = "Supermarket"
        
        let request = MKDirectionsRequest()
        request.source = MKMapItem.mapItemForCurrentLocation()
        print(MKMapItem.mapItemForCurrentLocation())
        request.destination = destination
        request.transportType = .Automobile
        request.requestsAlternateRoutes = false
        
        let directions = MKDirections(request: request)
        
        directions.calculateDirectionsWithCompletionHandler({(response:
            MKDirectionsResponse?, error: NSError?) in
            
            if let error = error {
                print(error.localizedDescription)
            } else {
                let route = response!.routes[0]
                self.mapView.addOverlay(route.polyline,
                    level: MKOverlayLevel.AboveRoads)
                self.steps = route.steps
                self.stepsTableView.reloadData()
            }
        })
    }
    
    func mapView(mapView: MKMapView, rendererForOverlay overlay: MKOverlay) -> MKOverlayRenderer {
            let renderer = MKPolylineRenderer(overlay: overlay)
            
            renderer.strokeColor = UIColor.blueColor()
            renderer.lineWidth = 5.0
            return renderer
    }
    
    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int{
        if let steps = self.steps {
            return steps.count
        }
        return 0
    }

    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell {
        var cell = tableView.dequeueReusableCellWithIdentifier("cell")
        if cell == nil {
            cell = UITableViewCell(style: .Default, reuseIdentifier: "cell")
        }
        cell?.textLabel?.text = self.steps?[indexPath.row].instructions
        return cell!
    }
} // end MapViewController