//
//  ViewController.swift
//  Chapter 8 Rehash
//
//  Created by City Life on 15/08/2015.
//  Copyright © 2015 PacktPub. All rights reserved.
//

import UIKit
import Photos

class InitialViewController: UIViewController , UITableViewDataSource, UITableViewDelegate  {
    
    @IBOutlet weak var assetsTableView: UITableView!
    var assets = [AssetInfo]()
    
    override func viewDidLoad() {
        super.viewDidLoad()
        
        if PHPhotoLibrary.authorizationStatus() == .Authorized {
            self.initAssets()
        }
        else {
            PHPhotoLibrary.requestAuthorization({ (status: PHAuthorizationStatus) -> Void in
                switch status {
                case .Authorized:
                    self.initAssets()
                default:
                    print("Not authorized")
                }
            })
        }
    }
    
    func initAssets(){
        self.assets = [AssetInfo]()
        let videos = PHAsset.fetchAssetsWithMediaType(.Video, options: nil)
        for i in 0..<videos.count {
            if let video = videos[i] as? PHAsset{
                let imageManager = PHImageManager.defaultManager()
                imageManager.requestAVAssetForVideo(video , options: nil, resultHandler: { (asset: AVAsset?, _: AVAudioMix?, _:[NSObject : AnyObject]?) -> Void in
                    if let urlAsset = asset as? AVURLAsset where urlAsset.playable {
                        let date:String
                        if let dateValue = urlAsset.creationDate?.dateValue{
                            let formatter = NSDateFormatter()
                            formatter.dateFormat = "dd-MM-yyyy"
                            date = formatter.stringFromDate(dateValue)
                        }else {
                            date = "Unknown date"
                        }
                        let assetInfo = AssetInfo(videoDate: date, videoUrl: urlAsset.URL)
                        imageManager.requestImageForAsset(video, targetSize: CGSizeMake(64, 64), contentMode: PHImageContentMode.AspectFill, options: nil, resultHandler: { (image:UIImage?, _:[NSObject : AnyObject]?) -> Void in
                            assetInfo.videoThumbnail = image
                            self.assets.append(assetInfo)
                            dispatch_async(dispatch_get_main_queue(), { () -> Void in
                                self.assetsTableView.reloadData()
                            })
                        })
                    }
                })
            }
        }
    } // end initAssets
    
    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    func tableView(tableView: UITableView, numberOfRowsInSection section: Int) -> Int{
        return assets.count + 1
    }
    
    func tableView(tableView: UITableView, cellForRowAtIndexPath indexPath: NSIndexPath) -> UITableViewCell{
        var cell = tableView.dequeueReusableCellWithIdentifier("assetcell")
        if cell == nil {
            cell = UITableViewCell(style: .Subtitle, reuseIdentifier: "assetcell")
        }
        
        let assetInfo = assets[indexPath.row]
        cell?.textLabel?.text = assetInfo.videoDate
        cell?.detailTextLabel?.text = assetInfo.videoUrl.absoluteString
        cell?.imageView?.image = assetInfo.videoThumbnail
        return cell!
    }
    
    
    
    
    func tableView(tableView: UITableView, didSelectRowAtIndexPath indexPath: NSIndexPath){
        if let recorderViewController = self.storyboard?.instantiateViewControllerWithIdentifier("recorderviewcontroller") as? RecorderViewController {
            recorderViewController.assetInfo = assets[indexPath.row]
            self.presentViewController(recorderViewController, animated: true, completion: nil)
        }
    }
    
    @IBAction func unwindToMainView(segue:UIStoryboardSegue) {
        self.initAssets()
    }
    
    
} // end InitialViewController

